@@ -480,13 +480,13 @@ function test_Poly_interface(Rx::AbstractAlgebra.PolyRing; reps = 30)
             @test is_monic(a) == isone(leading_coefficient(a))
          end
       end
-      
+
       @testset "reverse" begin
         p = x^2 + 2*x + 3
         @test reverse(p) !== p
         @test reverse(p) == 3*x^2 + 2*x + 1
         @test reverse(p, 2) == 3*x + 2
-        
+
         p = x^2 + 2*x
         reverse!(p)
         @test p == 2*x + 1
@@ -495,12 +495,12 @@ function test_Poly_interface(Rx::AbstractAlgebra.PolyRing; reps = 30)
         reverse!(p, 2)
         @test p == 2
       end
-      
+
       @testset "shifting" begin
         p = x^2 + 2*x + 3
         @test shift_left!(p, 1) == x^3 + 2*x^2 + 3*x
         @test shift_left!(p, 3) == x^6 + 2*x^5 + 3*x^4
-        
+
         p = x^2 + 2*x + 3
         @test shift_right!(p, 1) == x + 2
         @test shift_right!(p, 2) == zero(Rx)
@@ -721,10 +721,26 @@ function test_MatSpace_interface(S::MatSpace; reps = 20)
 
             t = transpose(a)
             @test t isa ST
+            @test base_ring(t) == base_ring(a)
             @test nrows(t) == ncols(S)
             @test ncols(t) == nrows(S)
             @test transpose(t) == a
             @test a == A
+
+            if nrows(S) == ncols(S)
+              # in-place transpose! only supported for square matrices
+              t = transpose!(deepcopy(a))
+              @test t isa ST
+              @test base_ring(t) == base_ring(a)
+              @test t == transpose(a)
+            end
+
+            z = zero_matrix(R, ncols(a), nrows(a))
+            t = transpose!(z, a)
+            @test t isa ST
+            @test base_ring(t) == base_ring(a)
+            @test t == transpose(a)
+            @test a == A
          end
       end
 
@@ -808,10 +824,14 @@ function test_Ring_interface_recursive(R::AbstractAlgebra.Ring; reps = 50)
    test_Poly_interface(Rx, reps = 2 + fld(reps, 2))
    Rxy, _ = polynomial_ring(R, [:x, :y])
    test_MPoly_interface(Rxy, reps = 2 + fld(reps, 2))
-   S = matrix_ring(R, rand(0:3))
-   test_MatAlgebra_interface(S, reps = 2 + fld(reps, 2))
-   S = matrix_space(R, rand(0:3), rand(0:3))
-   test_MatSpace_interface(S, reps = 2 + fld(reps, 2))
+   for d in 0:3
+     S = matrix_ring(R, d)
+     test_MatAlgebra_interface(S, reps = 2 + fld(reps, 8))
+   end
+   for (r,c) in ( (0,0), (1,0), (0,2), (2,2), (2,3), (3,2) )
+     S = matrix_space(R, r,c)
+     test_MatSpace_interface(S, reps = 2 + fld(reps, 10))
+   end
 end
 
 function test_Field_interface_recursive(R::AbstractAlgebra.Field; reps = 50)
