@@ -40,15 +40,8 @@ $R$.
 """
 symbols(R::MSeriesRing)
 
-@doc raw"""
-    characteristic(a::MSeriesRing)
-
-Return the characteristic of the base ring of the series `a`. If the
-characteristic is not known, an exception is raised.
-"""
-function characteristic(a::MSeriesRing)
-    return characteristic(base_ring(a))
-end
+characteristic(R::MSeriesRing) = characteristic(base_ring(R))
+is_known(::typeof(characteristic), R::MSeriesRing) = is_known(characteristic, base_ring(R))
 
 ###############################################################################
 #
@@ -210,4 +203,4 @@ end
 
 @varnames_interface Generic.power_series_ring(R::Ring, prec::Int, s)
 @varnames_interface Generic.power_series_ring(R::Ring, weights::Vector{Int}, prec::Int, s) macros=:no # use keyword `weights=...` instead
-@varnames_interface Generic.power_series_ring(R::Ring, prec::Vector{Int}, s) n=:no macros=:no # `n` variant would clash with line above; macro would be the same as for `prec::Int`    
+@varnames_interface Generic.power_series_ring(R::Ring, prec::Vector{Int}, s) n=:no macros=:no # `n` variant would clash with line above; macro would be the same as for `prec::Int`
