@@ -711,7 +711,7 @@ function Base.inv(a::AbsPowerSeriesRingElem{T}) where T <: FieldElement
     la = [prec]
     while la[end] > 1
         push!(la, div(la[end] + 1, 2))
-    end 
+    end
     two = R(2)
     two = _set_precision_raw!(two, prec)
     n = length(la) - 1
@@ -724,7 +724,7 @@ function Base.inv(a::AbsPowerSeriesRingElem{T}) where T <: FieldElement
         y = mul!(y, minus_a, x)
         y = add!(y, two)
         x = mul!(x, x, y)
-        n -= 1 
+        n -= 1
     end
     return x
 end
@@ -769,7 +769,7 @@ function compose(f::AbsPowerSeriesRingElem, g::AbsPowerSeriesRingElem; inner = n
              Alternatively, use directly f(g) or g(f)
              """)
   end
-            
+
   if inner == :second
     return _compose_right(f, g)
   else
@@ -850,18 +850,20 @@ function sqrt_classical(a::AbsPowerSeriesRingElem; check::Bool=true)
    asqrt = parent(a)()
    fit!(asqrt, prec)
    asqrt = _set_precision_raw!(asqrt, prec)
+   if prec <= aval2
+      asqrt = set_length!(asqrt, normalise(asqrt, prec))
+      return true, asqrt
+   end
    for n = 1:aval2
       asqrt = setcoeff!(asqrt, n - 1, R())
    end
-   if prec > aval2
-      c = coeff(a, aval)
-      if check && !is_square(c)
-         return false, zero(S)
-      end
-      g = sqrt(c; check=check)
-      asqrt = setcoeff!(asqrt, aval2, g)
-      g2 = g + g
+   c = coeff(a, aval)
+   if check && !is_square(c)
+      return false, zero(S)
    end
+   g = sqrt(c; check=check)
+   asqrt = setcoeff!(asqrt, aval2, g)
+   g2 = g + g
    p = R()
    for n = 1:prec - aval2 - 1
       c = R()
@@ -1017,7 +1019,7 @@ function Base.exp(a::AbsPowerSeriesRingElem{T}) where T <: FieldElement
       t = add!(t, one1)
       t = add!(t, a)
       x = mul!(x, x, t)
-      n -= 1 
+      n -= 1
    end
    if !isone(c)
       x *= c
