@@ -93,7 +93,10 @@ struct Partition{T} <: AbstractVector{T}
    Partition(part::AbstractVector{<:Integer}, check::Bool=true) =
       Partition(sum(part), part, check)
 
-   function Partition(n::Integer, part::AbstractVector{T}, check::Bool=true) where T
+   Partition(n::Integer, part::AbstractVector, check::Bool=true) =
+      Partition(n, collect(part), check)
+
+   function Partition(n::Integer, part::Vector{T}, check::Bool=true) where T
       if check
          issorted(part, rev=true) || sort!(part, rev=true)
          if length(part) > 0
@@ -464,7 +467,7 @@ end
 ###############################################################################
 
 @attributes mutable struct UniversalPolyRing{T <: RingElement} <: AbstractAlgebra.UniversalPolyRing{T}
-   mpoly_ring::AbstractAlgebra.MPolyRing{T}
+   base_ring::AbstractAlgebra.MPolyRing{T}
 
    function UniversalPolyRing{T}(
       R::Ring, s::Vector{Symbol}, internal_ordering::Symbol, cached::Bool=true
@@ -473,9 +476,7 @@ end
       return get_cached!(
          UnivPolyID, (R, s, internal_ordering), cached
       ) do
-         new{T}(
-            AbstractAlgebra.polynomial_ring_only(R, s; internal_ordering, cached=false)
-         )
+         new{T}(AbstractAlgebra.poly_ring(R, s; internal_ordering))
       end::UniversalPolyRing{T}
    end
 end
@@ -906,25 +907,25 @@ const PuiseuxSeriesElem{T} = Union{PuiseuxSeriesRingElem{T}, PuiseuxSeriesFieldE
    sym::Vector{Symbol}
    weighted_prec::Int # -1 if not weighted
 
-   function AbsMSeriesRing{T, S}(poly_ring::AbstractAlgebra.MPolyRing{T},
+   function AbsMSeriesRing(poly_ring::AbstractAlgebra.MPolyRing{T},
             prec::Vector{Int}, s::Vector{Symbol}, cached::Bool = true) where
-                          {T <: RingElement, S <: AbstractAlgebra.MPolyRingElem{T}}
+                          {T <: RingElement}
       U = elem_type(poly_ring)
       return get_cached!(AbsMSeriesID, (poly_ring, prec, s, -1), cached) do
          new{T, U}(poly_ring, prec, s, -1)
-      end::AbsMSeriesRing{T, S}
+      end::AbsMSeriesRing{T, U}
    end
 
-   function AbsMSeriesRing{T, S}(poly_ring::AbstractAlgebra.MPolyRing{T},
+   function AbsMSeriesRing(poly_ring::AbstractAlgebra.MPolyRing{T},
       weights::Vector{Int}, prec::Int, s::Vector{Symbol}, cached::Bool = true) where
-                    {T <: RingElement, S <: AbstractAlgebra.MPolyRingElem{T}}
+                    {T <: RingElement}
       U = elem_type(poly_ring)
       return get_cached!(AbsMSeriesID, (poly_ring, weights, s, prec), cached) do
          new{T, U}(poly_ring, weights, s, prec)
-      end::AbsMSeriesRing{T, S}
+      end::AbsMSeriesRing{T, U}
    end
 end
- 
+
 const AbsMSeriesID = CacheDictType{Tuple{Ring,
                                        Vector{Int}, Vector{Symbol}, Int}, Ring}()
 
@@ -1164,24 +1165,23 @@ struct MatRing{T <: NCRingElement} <: AbstractAlgebra.MatRing{T}
 end
 
 struct MatRingElem{T <: NCRingElement} <: AbstractAlgebra.MatRingElem{T}
-   base_ring::NCRing
-   entries::Matrix{T}
+   data::MatElem{T}
 
-   function MatRingElem{T}(R::NCRing, A::Matrix{T}) where T <: NCRingElement
-      @assert elem_type(R) === T
-      return new{T}(R, A)
+  function MatRingElem{TT}(A::MatElem{TT}) where TT <: NCRingElement
+    nrows(A) == ncols(A) || error("Matrix must be square")
+    return new{TT}(A)
    end
 end
 
-function MatRingElem{T}(R::NCRing, n::Int, A::Vector{T}) where T <: NCRingElement
-   @assert elem_type(R) === T
-   t = Matrix{T}(undef, n, n)
-   for i = 1:n, j = 1:n
-      t[i, j] = A[(i - 1) * n + j]
-   end
-   return MatRingElem{T}(R, t)
+MatRingElem(A::MatElem{TT}) where TT <: NCRingElement = MatRingElem{TT}(A)
+
+function MatRingElem(R::NCRing, n::Int, A::Vector{T}) where T <: NCRingElement
+   t = matrix(R, n, n, A)
+   return MatRingElem(t)
 end
 
+matrix(A::MatRingElem{T}) where {T <: NCRingElement} = A.data::dense_matrix_type(T)
+
 ###############################################################################
 #
 #   FreeAssociativeAlgebra / FreeAssociativeAlgebraElem
@@ -1212,6 +1212,13 @@ mutable struct FreeAssociativeAlgebraElem{T <: RingElement} <: AbstractAlgebra.F
    coeffs::Vector{T}
    exps::Vector{Vector{Int}}  # TODO: Int -> UInt8 for nvars < 256, etc
    length::Int
+
+   function FreeAssociativeAlgebraElem{T}(parent::FreeAssociativeAlgebra{T},
+         coeffs::Vector{T},
+         exps::Vector{Vector{Int}},
+         length::Int) where T
+      return new{T}(parent, coeffs, exps, length)
+   end
 end
 
 # the iterators for coeffs, terms, etc. are shared with MPoly. Just this remains
@@ -1383,7 +1390,7 @@ julia> Generic.inj_proj_mat(ZZ, 2, 5, 3)
 ```
 """
 struct InjProjMat{T <: RingElement} <: AbstractAlgebra.MatElem{T}
-   R
+   R::NCRing
    n::Int #Rows
    m::Int #Cols
    s::Int
