@@ -229,7 +229,7 @@ function factor(a::LaurentMPolyWrap)
    for (p, e) in f
       d[LaurentMPolyWrap(R, p)] = e
    end
-   return Fac(LaurentMPolyWrap(R, unit(f), ad), d)
+   return Fac(LaurentMPolyWrap(R, unit(f)::typeof(a.mpoly), ad), d)
 end
 
 function factor_squarefree(a::LaurentMPolyWrap)
@@ -240,7 +240,7 @@ function factor_squarefree(a::LaurentMPolyWrap)
    for (p, e) in f
       d[LaurentMPolyWrap(R, p)] = e
    end
-   return Fac(LaurentMPolyWrap(R, unit(f), ad), d)
+   return Fac(LaurentMPolyWrap(R, unit(f)::typeof(a.mpoly), ad), d)
 end
 
 ###############################################################################
@@ -549,6 +549,13 @@ mutable struct LaurentMPolyBuildCtx{T, S}
     coeffs::Vector{T}
     exps::Vector{Vector{Int}}
     parent::S
+
+   function LaurentMPolyBuildCtx{T, S}(
+         coeffs::Vector{T},
+         exps::Vector{Vector{Int}},
+         parent::S) where {T, S}
+      return new{T, S}(coeffs, exps, parent)
+   end
 end
 
 function MPolyBuildCtx(R::AbstractAlgebra.LaurentMPolyRing{T}) where T
