@@ -73,14 +73,8 @@ isone(a::GFElem{T}) where T <: Integer = a.d == 1
 
 is_unit(a::GFElem) = a.d != 0
 
-@doc raw"""
-    characteristic(R::GFField)
-
-Return the characteristic of the given finite field.
-"""
-function characteristic(R::GFField)
-   return R.p
-end
+characteristic(R::GFField) = R.p
+is_known(::typeof(characteristic), ::GFField) = true
 
 @doc raw"""
     order(R::GFField)
