@@ -46,12 +46,6 @@
    b = T(2)
    @test is_perfect(TT)
 
-   @test a in [a, b]
-   @test a in [b, a]
-   @test !(a in [b])
-   @test a in keys(Dict(a => 1))
-   @test !(b in keys(Dict(a => 1)))
-
    # trivial rings can not be fields
    R = residue_ring(ZZ, 1)[1]
    @test is_trivial(R)
@@ -381,7 +375,7 @@ end
 
    f2, s2 = is_square_with_sqrt(f)
 
-   @test !f2   
+   @test !f2
 end
 
 @testset "Generic.FracFieldElem.gcd" begin
