@@ -125,14 +125,6 @@
 
       @test collect(exponent_words(varlist[1] + 1)) == [Int[1], Int[]]
       @test isone(varlist[1]^0)
-
-      _, varlist = polynomial_ring(QQ, var_names)
-      y = varlist[1]
-      @test x in [x, y]
-      @test x in [y, x]
-      @test !(x in [y])
-      @test x in keys(Dict(x => 1))
-      @test !(y in keys(Dict(x => 1)))
    end
 end
 
@@ -259,7 +251,7 @@ end
 
    S, (x,y) = free_associative_algebra(QQ, [:x, :y])
    f = x^2 + x*y^2*x + QQ(5)*y - QQ(1//2)*y*x
-   
+
    @test 2 + f == QQ(2) + f
    @test f + 2 == f + QQ(2)
    @test 1//2 + f == QQ(1//2) + f
