@@ -22,20 +22,22 @@
 end
 
 @testset "Generic.Poly.constructors" begin
-   S1 = PolyRing(ZZ)
-   S2 = PolyRing(ZZ)
+   S1 = AbstractAlgebra.poly_ring(ZZ)
+   S2 = AbstractAlgebra.poly_ring(ZZ)
 
    @test S1 !== S2
    @test isa(S1, Generic.PolyRing)
 
    R, x = ZZ["x"]
-   S1 = R["y"]
-   S2 = ZZ["x"]["y"]
+   S1, y = R["y"]
+   @test isa(y, PolyRingElem)
+   S2, (x,y) = ZZ["x"]["y"]
+   @test isa(y, PolyRingElem)
 
    @test polynomial_ring(R, "y", cached = true)[1] === polynomial_ring(R, "y", cached = true)[1]
    @test polynomial_ring(R, "y", cached = true)[1] !== polynomial_ring(R, "y", cached = false)[1]
 
-   for (S, y) in (S1, S2)
+   for S in (S1, S2)
       @test base_ring(S) === R
       @test coefficient_ring(S) === R
       @test coefficient_ring_type(S) === typeof(R)
@@ -46,8 +48,6 @@ end
 
       @test R isa AbstractAlgebra.Ring
       @test S isa Generic.PolyRing
-
-      @test isa(y, PolyRingElem)
    end
 
    R, x = polynomial_ring(ZZ, "x")
@@ -95,13 +95,6 @@ end
       n = S([ZZ(1), ZZ(2), ZZ(3)])
 
       @test isa(n, PolyRingElem)
-
-      @test x in [x, y]
-      @test x in [y, x]
-      @test !(x in [y])
-
-      @test x in keys(Dict(x => 1))
-      @test !(y in keys(Dict(x => 1)))
    end
 
    @testset "Generic.Poly.constructors.varname" begin
@@ -121,6 +114,24 @@ end
       @test Rx1 == Rx6
       @test Rx1 == (Rx7, x)
    end
+
+   @testset "Generic.Poly.constructors.getindex" begin
+      S, vs = ZZ[:x][:y]
+      @test S isa Generic.PolyRing{Generic.Poly{BigInt}}
+      @test length(vs) == 2
+      for v in vs
+         @test v isa Generic.Poly{Generic.Poly{BigInt}}
+         @test parent(v) == S
+      end
+
+      S, vs = ZZ[:x][:y][:z]
+      @test S isa Generic.PolyRing{Generic.Poly{Generic.Poly{BigInt}}}
+      @test length(vs) == 3
+      for v in vs
+         @test v isa Generic.Poly{Generic.Poly{Generic.Poly{BigInt}}}
+         @test parent(v) == S
+      end
+   end
 end
 
 @testset "Generic.Poly.iterators" begin
@@ -2994,7 +3005,7 @@ end
    @test map_coefficients(t -> F(t) + 2, f) == 3y^2 + 5y^3 + 4y^6
 
    let
-      Q = matrix_ring(QQ, 2) 
+      Q = matrix_ring(QQ, 2)
       Qz, z = Q[:z]
       Qx, x = QQ[:x]
       f = map_coefficients(c -> c * (2*one(Q)), x; parent = Qz)
@@ -3043,7 +3054,7 @@ end
       d = min(num, degree(f))
       @test collect(Base.Iterators.take(V, d)) == collect(Base.Iterators.take(W, d))
    end
-end 
+end
 
 @testset "Generic.Poly.zero_rings" begin
   R, = residue_ring(ZZ, 1)
