@@ -98,13 +98,6 @@ end
    l = T(t)
 
    @test isa(l, Generic.PuiseuxSeriesElem)
-
-   @test x in [x, y]
-   @test x in [y, x]
-   @test !(x in [y])
-
-   @test x in keys(Dict(x => 1))
-   @test !(y in keys(Dict(x => 1)))
 end
 
 @testset "Generic.PuiseuxSeries.printing" begin
@@ -810,7 +803,7 @@ end
 
       @test isequal(integral(derivative(f)) + const_coeff, f)
    end
- 
+
    # Inexact field
    S, x = puiseux_series_field(RealField, 10, "x")
 
