@@ -29,7 +29,7 @@
          @test elem_type(Generic.UniversalPolyRing{elem_type(R)}) == Generic.UnivPoly{elem_type(R)}
          @test parent_type(Generic.UnivPoly{elem_type(R)}) == Generic.UniversalPolyRing{elem_type(R)}
 
-         @test base_ring(S) === R
+         @test coefficient_ring(S) === R
          @test coefficient_ring(S) === R
          @test coefficient_ring_type(S) === typeof(R)
 
@@ -49,7 +49,7 @@
          V = [R(rand(-10:10)) for i in 1:5]
          nused = rand(0:3)
          W = [[rand(0:100) for i in 1:nused] for i = 1:5]
-         
+
          f1 = S(V, W)
 
          @test isa(f1, UniversalPolyRingElem)
@@ -75,15 +75,6 @@
 
          @test f1 == f3
 
-         @test x in [x, y]
-         @test x in [y, x]
-         @test y in [y, z]
-         @test !(x in [y])
-         @test !(y in [x])
-         @test x in keys(Dict(x => 1))
-         @test !(y in keys(Dict(x => 1)))
-         @test !(y in keys(Dict(z => 1)))
-
          S2, x = universal_polynomial_ring(R, :x => 1:3; internal_ordering=ord)
 
          @test length(x) == 3
@@ -137,10 +128,10 @@ end
          @test parent(f2) === S
          @test parent(f3) === S
 
-         @test base_ring(S) === R
-         @test base_ring(f1) === R
-         @test base_ring(f2) === R
-         @test base_ring(f3) === R
+         @test coefficient_ring(S) === R
+         @test coefficient_ring(f1) === R
+         @test coefficient_ring(f2) === R
+         @test coefficient_ring(f3) === R
 
          @test nvars(S) == 3
 
@@ -428,11 +419,11 @@ end
          @test f + g == g + f
          @test f + h == h + f
          @test g + h == h + g
-         
+
          @test f - g == -(g - f)
          @test f - h == -(h - f)
          @test g - h == -(h - g)
-         
+
          @test f*g == g*f
          @test f*h == h*f
          @test g*h == h*g
@@ -678,10 +669,10 @@ end
          n = rand(0:3)
          shift = [rand(0:5) for i in 1:n]
          defl = [rand(1:5) for i in 1:n]
-         
+
          fi = inflate(f, shift, defl)
 
-         @test deflate(fi, shift, defl) == f        
+         @test deflate(fi, shift, defl) == f
          @test deflate(inflate(f, defl), defl) == f
 
          shift2, defl2 = deflation(fi)
@@ -809,7 +800,7 @@ end
             @test div(h, h) == 1
             @test div(h*f, h) == f
             @test div(h*g, h) == g
-            
+
             q, r = divrem(h, h)
             @test q == 1 && r == 0
             q, r = divrem(h*f, h)
@@ -974,6 +965,7 @@ end
          @test evaluate(f, V) == f(V...)
          @test evaluate(f, V) == f([ZZ(v) for v in V]...)
          @test evaluate(f, V) == f([U(v) for v in V]...)
+         @test evaluate(f, V) == evaluate(f, collect(1:n), V)
 
          @test evaluate(g, V) == evaluate(g, [R(v) for v in V])
          @test evaluate(g, V) == evaluate(g, [ZZ(v) for v in V])
@@ -981,13 +973,11 @@ end
          @test evaluate(g, V) == g(V...)
          @test evaluate(g, V) == g([ZZ(v) for v in V]...)
          @test evaluate(g, V) == g([U(v) for v in V]...)
+         @test evaluate(g, V) == evaluate(g, collect(1:n), V)
 
-         @test evaluate(h, V) == evaluate(h, [R(v) for v in V])
-         @test evaluate(h, V) == evaluate(h, [ZZ(v) for v in V])
-         @test evaluate(h, V) == evaluate(h, [U(v) for v in V])
-         @test evaluate(h, V) == h(V...)
-         @test evaluate(h, V) == h([ZZ(v) for v in V]...)
-         @test evaluate(h, V) == h([U(v) for v in V]...)
+         @test parent(evaluate(g, V)) == R
+         @test parent(evaluate(g, collect(1:n), V)) == S
+         @test evaluate(h, [1,2,3,4]) == evaluate(h, [1,2,3,5])
 
          V = [rand(-10:10) for v in 1:2]
 
@@ -998,16 +988,20 @@ end
          @test evaluate(f, [1, 3], [V[1], V[2]]) == evaluate(f, [1, 3], [ZZ(v) for v in V[1:2]])
          @test evaluate(f, [1, 3], [V[1], V[2]]) == f(x=V[1], z=V[2])
          @test evaluate(f, [1, 3], [V[1], V[2]]) == f(z=V[2], x=V[1])
+         @test evaluate(f, [1, 3], [V[1], V[2]]) == f(x=V[1], z=V[2], w=0)
+         @test parent(evaluate(f, [1, 3], [V[1], V[2]])) == S
 
          @test evaluate(g, [1], [V[1]]) == evaluate(g, [1], [R(V[1])])
          @test evaluate(g, [1], [V[1]]) == evaluate(g, [1], [ZZ(V[1])])
          @test evaluate(g, [1, 3], [V[1], V[2]]) == evaluate(g, [1, 3], [R(v) for v in V[1:2]])
          @test evaluate(g, [1, 3], [V[1], V[2]]) == evaluate(g, [1, 3], [ZZ(v) for v in V[1:2]])
+         @test parent(evaluate(g, [1, 3], [V[1], V[2]])) == S
 
          @test evaluate(h, [1], [V[1]]) == evaluate(h, [1], [R(V[1])])
          @test evaluate(h, [1], [V[1]]) == evaluate(h, [1], [ZZ(V[1])])
          @test evaluate(h, [1, 3], [V[1], V[2]]) == evaluate(h, [1, 3], [R(v) for v in V[1:2]])
          @test evaluate(h, [1, 3], [V[1], V[2]]) == evaluate(h, [1, 3], [ZZ(v) for v in V[1:2]])
+         @test parent(evaluate(h, [1, 3], [V[1], V[2]])) == S
 
          @test evaluate(x, [1], [y]) == evaluate(z, [3], [y])
       end
@@ -1116,9 +1110,9 @@ end
       @test length(g) == length(g1)
       @test length(h) == length(h1)
 
-      @test base_ring(f1) === U
-      @test base_ring(g1) === U
-      @test base_ring(h1) === U
+      @test coefficient_ring(f1) === U
+      @test coefficient_ring(g1) === U
+      @test coefficient_ring(h1) === U
 
       f2 = map_coefficients(x->x^2, f)
       g2 = map_coefficients(x->x^2, g)
@@ -1145,7 +1139,7 @@ end
 
       f1 = deepcopy(f)
       f1 = add!(f1, g, h)
-      
+
       @test f1 == g + h
       @test f == 3x^3 + 2x^2 + x + 4
 
